@@ -30,7 +30,6 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <string.h>
-#include <libgnomevfs/gnome-vfs.h>
 
 #include <libanjuta/anjuta-plugin-manager.h>
 #include <libanjuta/anjuta-marshal.h>
@@ -2474,7 +2473,8 @@ anjuta_plugin_manager_activate_plugins (AnjutaPluginManager *plugin_manager,
 			icon_path = g_strconcat (PACKAGE_PIXMAPS_DIR"/",
 									 icon_filename, NULL);
 			/* DEBUG_PRINT ("Icon: %s", icon_path); */
-			label = g_strconcat (_("Loaded: "), title, "...", NULL);
+			/* Avoid space in translated string */
+			label = g_strconcat (_("Loaded:"), " ", title, "...", NULL);
 			icon_pixbuf = gdk_pixbuf_new_from_file (icon_path, NULL);
 			if (!icon_pixbuf)
 				g_warning ("Plugin does not define Icon: No such file %s",
