@@ -14,7 +14,7 @@
  *
  *	You should have received a copy of the GNU General Public License
  *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "window.h"
@@ -24,7 +24,7 @@
 
 #include <libanjuta/anjuta-plugin.h>
 
-#include <glib/gstrfuncs.h>
+#include <glib.h>
 
 #include <ctype.h>
 
@@ -225,7 +225,7 @@ cg_window_fetch_boolean (CgWindow *window,
 
 static void
 cg_window_set_heap_value (CgWindow *window,
-                          NPWValueHeap *values,
+                          GHashTable *values,
                           GType type,
                           const gchar *name,
                           const gchar *id)
@@ -242,16 +242,16 @@ cg_window_set_heap_value (CgWindow *window,
 	{
 	case G_TYPE_STRING:
 		text = cg_window_fetch_string (window, id);
-		npw_value_heap_set_value (values, value, text, NPW_VALID_VALUE);
+		npw_value_set_value (value, text, NPW_VALID_VALUE);
 		g_free (text);
 		break;
 	case G_TYPE_INT:
 		int_value = cg_window_fetch_integer (window, id);
 		sprintf (int_buffer, "%d", int_value);
-		npw_value_heap_set_value (values, value, int_buffer, NPW_VALID_VALUE);
+		npw_value_set_value (value, int_buffer, NPW_VALID_VALUE);
 		break;
 	case G_TYPE_BOOLEAN:
-		npw_value_heap_set_value (values, value,
+		npw_value_set_value (value,
 			cg_window_fetch_boolean (window, id) ? "1" : "0", NPW_VALID_VALUE);
 
 		break;
@@ -615,7 +615,7 @@ cg_window_go_properties_transform_func (GHashTable *table,
 	cg_transform_flags (table, "Flags", GO_PROPERTY_FLAGS);
 
 	paramspec = g_hash_table_lookup (table, "ParamSpec");
-	if (strcmp (paramspec, "g_param_spec_string") == 0)
+	if (paramspec && (strcmp (paramspec, "g_param_spec_string") == 0))
 		cg_transform_string (table, "Default");
 }
 
@@ -865,7 +865,7 @@ cg_window_get_dialog (CgWindow *window)
 	return GTK_DIALOG (CG_WINDOW_PRIVATE (window)->window);
 }
 
-NPWValueHeap *
+GHashTable *
 cg_window_create_value_heap (CgWindow *window)
 {
 	static const gchar *LICENSES[] = {
@@ -875,7 +875,7 @@ cg_window_create_value_heap (CgWindow *window)
 	};
 
 	CgWindowPrivate *priv;
-	NPWValueHeap *values;
+	GHashTable *values;
 	NPWValue *value;
 	GError *error;
 	gint license_index;
@@ -934,10 +934,10 @@ cg_window_create_value_heap (CgWindow *window)
 		g_free (text);
 
 		value = npw_value_heap_find_value (values, "BaseTypePrefix");
-		npw_value_heap_set_value (values, value, base_prefix, NPW_VALID_VALUE);
+		npw_value_set_value (value, base_prefix, NPW_VALID_VALUE);
 		
 		value = npw_value_heap_find_value (values, "BaseTypeSuffix");
-		npw_value_heap_set_value (values, value, base_suffix, NPW_VALID_VALUE);
+		npw_value_set_value (value, base_suffix, NPW_VALID_VALUE);
 		
 		g_free (base_prefix);
 		g_free (base_suffix);
@@ -1002,17 +1002,17 @@ cg_window_create_value_heap (CgWindow *window)
 	license_index = cg_window_fetch_integer (window, "license");
 	value = npw_value_heap_find_value (values, "License");
 
-	npw_value_heap_set_value(values, value, LICENSES[license_index],
+	npw_value_set_value(value, LICENSES[license_index],
 	                         NPW_VALID_VALUE);
 
 	header_file = g_path_get_basename (cg_window_get_header_file (window));
 	source_file = g_path_get_basename (cg_window_get_source_file (window));
 	
 	value = npw_value_heap_find_value (values, "HeaderFile");
-	npw_value_heap_set_value (values, value, header_file, NPW_VALID_VALUE);
+	npw_value_set_value (value, header_file, NPW_VALID_VALUE);
 	
 	value = npw_value_heap_find_value (values, "SourceFile");
-	npw_value_heap_set_value (values, value, source_file, NPW_VALID_VALUE);
+	npw_value_set_value (value, source_file, NPW_VALID_VALUE);
 	
 	g_free (header_file);
 	g_free (source_file);
@@ -1105,7 +1105,7 @@ cg_window_set_add_to_project (CgWindow *window,
 	button = GTK_CHECK_BUTTON (glade_xml_get_widget (priv->gxml,
 	                                                 "add_project"));
 
-	return gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), enable);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), enable);
 }
 
 void
@@ -1119,7 +1119,7 @@ cg_window_set_add_to_repository (CgWindow *window,
 	button = GTK_CHECK_BUTTON (glade_xml_get_widget (priv->gxml,
 	                                                 "add_repository"));
 
-	return gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), enable);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), enable);
 }
 
 gboolean
