@@ -25,10 +25,7 @@
 #include <glib/gi18n.h>
 #include "search-box.h"
 
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkentry.h>
+#include <gtk/gtk.h>
 
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-status.h>
@@ -445,7 +442,7 @@ search_box_init (SearchBox *object)
 					  G_CALLBACK (on_search_focus_out),
 					  object);	
 	
-	private->case_check = gtk_check_button_new_with_label (_("Case sensitive"));
+	private->case_check = gtk_check_button_new_with_label (_("Match case"));
 	
 	private->search_button = gtk_button_new ();
 	gtk_button_set_image (GTK_BUTTON (private->search_button), search);
