@@ -391,12 +391,12 @@ icell_get_char (IAnjutaEditorCell* icell, gint index, GError** e)
 }
 
 static IAnjutaEditorAttribute
-icell_get_attribute (IAnjutaEditorCell *cell, GError **e)
+icell_get_attribute (IAnjutaEditorCell *icell, GError **e)
 {
+	TextEditorCell* cell = TEXT_EDITOR_CELL(icell);
 	IAnjutaEditorAttribute attrib = IANJUTA_EDITOR_TEXT;
 	TextEditorAttrib text_attrib =
-		text_editor_get_attribute (TEXT_EDITOR_CELL (cell)->priv->editor,
-								   TEXT_EDITOR_CELL (cell)->priv->position);
+		text_editor_get_attribute (cell->priv->editor, cell->priv->position);
 	switch (text_attrib)
 	{
 		case TEXT_EDITOR_ATTRIB_TEXT:
@@ -492,11 +492,8 @@ static gboolean
 iiter_next (IAnjutaIterable* iter, GError** e)
 {
 	TextEditorCell* cell = TEXT_EDITOR_CELL(iter);
-	gint length;
 	gint old_position;
 	
-	length = ianjuta_editor_get_length (IANJUTA_EDITOR (cell->priv->editor),
-										NULL);
 	old_position = cell->priv->position;
 	cell->priv->position = scintilla_send_message (SCINTILLA (cell->priv->editor->scintilla),
 												   SCI_POSITIONAFTER, old_position,
@@ -533,11 +530,9 @@ static gboolean
 iiter_last (IAnjutaIterable* iter, GError** e)
 {
 	TextEditorCell* cell = TEXT_EDITOR_CELL(iter);
-	gint length;
-	
-	length = ianjuta_editor_get_length (IANJUTA_EDITOR (cell->priv->editor),
-										NULL);
-	text_editor_cell_set_position (TEXT_EDITOR_CELL (iter), length);
+	cell->priv->position =
+		scintilla_send_message (SCINTILLA (cell->priv->editor->scintilla),
+								SCI_GETLENGTH, 0, 0);
 	return TRUE;
 }
 
@@ -562,69 +557,88 @@ iiter_foreach (IAnjutaIterable* iter, GFunc callback, gpointer data, GError** e)
 static gboolean
 iiter_set_position (IAnjutaIterable* iter, gint position, GError** e)
 {
-	gint i, saved_position;
-	gboolean out_of_range = FALSE;
-	
+	gint i;
+	gboolean within_range = TRUE;
+	gint old_byte_position = 0, new_byte_position = 0;
 	TextEditorCell* cell = TEXT_EDITOR_CELL(iter);
 	
+	if (position < 0)
+	{
+		/* Set to end-iter (length of the doc) */
+		cell->priv->position =
+			scintilla_send_message (SCINTILLA (cell->priv->editor->scintilla),
+									SCI_GETLENGTH, 0, 0);
+		return within_range;
+	}
+	
 	/* FIXME: Find more optimal solution */
-	saved_position = cell->priv->position;
-	
-	cell->priv->position = 0;
-	
-	/* Iterate untill the we reach given position */
+	/* Iterate untill the we reach given character position */
+	old_byte_position = 0;
 	for (i = 0; i < position; i++)
 	{
-		if (!ianjuta_iterable_next (iter, NULL))
+		new_byte_position =
+			scintilla_send_message (SCINTILLA (cell->priv->editor->scintilla),
+									SCI_POSITIONAFTER, old_byte_position, 0);	
+		if (old_byte_position == new_byte_position)
 		{
-			out_of_range = TRUE;
+			/* Out of range. set to end-iter */
+			DEBUG_PRINT ("Out of range: setting pos at %d", new_byte_position);
+			within_range = FALSE;
 			break;
 		}
+		old_byte_position = new_byte_position;
 	}
-	
-	if (out_of_range)
-	{
-		/* out of range. Restore previous position */
-		cell->priv->position = saved_position;
-		return FALSE;
-	}
-	return TRUE;
+	cell->priv->position = new_byte_position;
+	DEBUG_PRINT ("Editor byte position set at: %d", cell->priv->position);
+	return within_range;
 }
 
 static gint
-iiter_get_position(IAnjutaIterable* iter, GError** e)
+iiter_get_position (IAnjutaIterable* iter, GError** e)
 {
-	gchar *text;
 	gint char_position = 0;
 	
 	TextEditorCell* cell = TEXT_EDITOR_CELL(iter);
 	
+	/* FIXME: Find a more optimal solution */
 	if (cell->priv->position > 0)
 	{
-		/* FIXME: Find a more optimal solution */
-		text = ianjuta_editor_get_text (IANJUTA_EDITOR (cell->priv->editor), 0,
-										cell->priv->position,
-										NULL);
-		char_position = g_utf8_strlen (text, -1);
-		g_free (text);
+		gchar *data =
+			(gchar *) aneditor_command (TEXT_EDITOR
+										(cell->priv->editor)->editor_id,
+										ANE_GETTEXTRANGE, 0,
+										cell->priv->position);
+		char_position = g_utf8_strlen (data, -1);
+		g_free (data);
 	}
+	DEBUG_PRINT ("Byte pos = %d, char position = %d", cell->priv->position,
+				 char_position);
 	return char_position;
 }
 
 static gint
-iiter_get_length(IAnjutaIterable* iter, GError** e)
+iiter_get_length (IAnjutaIterable* iter, GError** e)
 {
-	gchar *text;
-	gint length;
+	gint byte_length;
 	
 	TextEditorCell* cell = TEXT_EDITOR_CELL(iter);
 	
 	/* FIXME: Find a more optimal solution */
-	text = ianjuta_editor_get_text (IANJUTA_EDITOR (cell->priv->editor), 0, -1,
-									NULL);
-	length = g_utf8_strlen (text, -1);
-	g_free (text);
-	return length;
+	byte_length = scintilla_send_message (SCINTILLA (cell->priv->editor->scintilla),
+										  SCI_GETLENGTH, 0, 0);
+	if (byte_length > 0)
+	{
+		gchar *data;
+		gint char_length;
+		
+		data = (gchar *) aneditor_command (TEXT_EDITOR
+										   (cell->priv->editor)->editor_id,
+										   ANE_GETTEXTRANGE, 0, byte_length);
+		char_length = g_utf8_strlen (data, -1);
+		g_free (data);
+		return char_length;
+	}
+	return 0;
 }
 
 static IAnjutaIterable *
@@ -645,6 +659,55 @@ iiter_assign (IAnjutaIterable *iter, IAnjutaIterable *src_iter, GError **e)
 	cell->priv->position = src->priv->position;
 }
 
+static gint
+iiter_compare (IAnjutaIterable *iter, IAnjutaIterable *iter2, GError **e)
+{
+	gint delta;
+	TextEditorCell *cell = TEXT_EDITOR_CELL (iter);
+	TextEditorCell *cell2 = TEXT_EDITOR_CELL (iter2);
+	delta = cell->priv->position - cell2->priv->position;
+	return (delta == 0)? 0 : ((delta > 0)? 1 : -1);
+}
+
+static gint
+iiter_diff (IAnjutaIterable *iter, IAnjutaIterable *iter2, GError **e)
+{
+	gint diff = 0;
+	TextEditorCell *cell = TEXT_EDITOR_CELL (iter);
+	TextEditorCell *cell2 = TEXT_EDITOR_CELL (iter2);
+	
+	if (cell->priv->position == cell2->priv->position)
+	{
+		return 0;
+	}
+	
+	/* FIXME: Find more optimal solution */
+	/* Iterate until we reach larger iter position */
+	if (cell->priv->position > cell2->priv->position)
+	{
+		gint byte_position = cell2->priv->position;
+		while (byte_position < cell->priv->position)
+		{
+			byte_position =
+				scintilla_send_message (SCINTILLA (cell->priv->editor->scintilla),
+										SCI_POSITIONAFTER, byte_position, 0);
+			diff--;
+		}
+	}
+	else
+	{
+		gint byte_position = cell->priv->position;
+		while (byte_position < cell2->priv->position)
+		{
+			byte_position =
+				scintilla_send_message (SCINTILLA (cell->priv->editor->scintilla),
+										SCI_POSITIONAFTER, byte_position, 0);
+			diff++;
+		}
+	}
+	return diff;
+}
+
 static void
 iiter_iface_init(IAnjutaIterableIface* iface)
 {
@@ -658,6 +721,8 @@ iiter_iface_init(IAnjutaIterableIface* iface)
 	iface->get_length = iiter_get_length;
 	iface->clone = iiter_clone;
 	iface->assign = iiter_assign;
+	iface->compare = iiter_compare;
+	iface->diff = iiter_diff;
 }
 
 ANJUTA_TYPE_BEGIN(TextEditorCell, text_editor_cell, G_TYPE_OBJECT);
