@@ -26,6 +26,9 @@
 #include <glib/gi18n.h>
 #include <string.h>
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/anjuta-plugin.h>
+#include <libanjuta/anjuta-async-notify.h>
+#include <libanjuta/interfaces/ianjuta-vcs.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
@@ -60,6 +63,8 @@ struct _FileModelPrivate
 	gboolean filter_binary;
 	gboolean filter_hidden;
 	gboolean filter_backup;
+	
+	GtkTreeView* view;
 };
 
 struct _FileModelAsyncData
@@ -102,7 +107,7 @@ file_model_filter_file (FileModel* model,
 
 static void
 file_model_add_dummy (FileModel* model,
-					 GtkTreeIter* iter)
+					  GtkTreeIter* iter)
 {
 	GtkTreeStore* store = GTK_TREE_STORE (model);
 	GtkTreeIter dummy;
@@ -114,6 +119,163 @@ file_model_add_dummy (FileModel* model,
 					    -1);
 }
 
+typedef struct
+{
+	FileModel* model;
+	GtkTreeRowReference* ref;
+} VcsData;
+
+#define EMBLEM_ADDED "vcs-added.png"
+#define EMBLEM_CONFLICT "vcs-conflict.png"
+#define EMBLEM_DELETED "vcs-deleted.png"
+#define EMBLEM_IGNORED "vcs-ignored.png"
+#define EMBLEM_LOCKED "vcs-locked.png"
+#define EMBLEM_UNVERSIONED "vcs-unversioned.png"
+#define EMBLEM_UPDATED "vcs-updated.png"
+#define EMBLEM_MODIFIED "vcs-modified.png"
+
+#define COMPOSITE_ALPHA 225
+
+static GdkPixbuf* 
+get_vcs_emblem (AnjutaVcsStatus status)
+{
+	GdkPixbuf* emblem ;
+	switch (status)
+	{
+		case ANJUTA_VCS_STATUS_NONE:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_UPDATED, NULL);
+			break;
+		case ANJUTA_VCS_STATUS_ADDED:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_ADDED, NULL);
+			break;
+		case ANJUTA_VCS_STATUS_MODIFIED:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_MODIFIED, NULL);
+			break;
+		case ANJUTA_VCS_STATUS_DELETED:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_DELETED, NULL);
+			break;
+		case ANJUTA_VCS_STATUS_CONFLICTED:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_CONFLICT, NULL);
+			break;
+		case ANJUTA_VCS_STATUS_LOCKED:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_LOCKED, NULL);
+			break;
+		case ANJUTA_VCS_STATUS_UNVERSIONED:
+			emblem = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"EMBLEM_UNVERSIONED, NULL);
+			break;
+		default:
+			emblem = NULL;
+	}
+	DEBUG_PRINT ("emblem found: %d", emblem != NULL);
+	return emblem;
+}
+
+static void
+file_model_vcs_status_callback(GFile *file,
+							   AnjutaVcsStatus status,
+							   gpointer user_data)
+{
+	VcsData* data = user_data;
+	gchar* path = g_file_get_path (file);
+	
+	DEBUG_PRINT ("Status of %s = %d", path, status);
+	
+	GtkTreePath* tree_path = gtk_tree_row_reference_get_path (data->ref);
+	if (tree_path)
+	{
+		GdkPixbuf* file_icon = NULL;
+		GdkPixbuf* emblem = NULL;
+		GtkTreeIter iter;
+		GtkTreeModel* model = gtk_tree_row_reference_get_model (data->ref);
+
+		gtk_tree_model_get_iter (model,
+								 &iter,
+								 tree_path);
+		
+		emblem = get_vcs_emblem (status);
+		if (emblem)
+		{
+			gtk_tree_model_get (model, &iter,
+								COLUMN_PIXBUF, &file_icon,
+								-1);
+			if (file_icon)
+			{
+				gdk_pixbuf_composite (emblem,
+									  file_icon,
+									  0, 0,
+									  gdk_pixbuf_get_width (file_icon),
+									  gdk_pixbuf_get_height (file_icon),
+									  0, 0,
+									  1, 1,
+									  GDK_INTERP_BILINEAR,
+									  COMPOSITE_ALPHA);
+				gtk_tree_store_set (GTK_TREE_STORE (model),
+									&iter,
+									COLUMN_PIXBUF,
+									file_icon,
+									-1);
+				DEBUG_PRINT ("%s", "setting emblem");
+				
+				g_object_unref (file_icon);
+			}
+			g_object_unref (emblem);
+		}
+		
+
+		gtk_tree_store_set (GTK_TREE_STORE (model),
+							&iter,
+							COLUMN_STATUS,
+							status,
+							-1);
+		gtk_tree_path_free (tree_path);
+	}
+	g_free(path);
+}
+
+static void
+file_model_free_vcs_data (VcsData *data)
+{
+	gtk_tree_row_reference_free (data->ref);
+	g_free (data);
+}
+
+static void
+file_model_get_vcs_status (FileModel* model,
+						   GtkTreeIter* iter,
+						   GFile* file)
+{	
+	GtkTreePath* path = gtk_tree_model_get_path (GTK_TREE_MODEL(model),
+												 iter);
+	FileModelPrivate* priv = FILE_MODEL_GET_PRIVATE(model);	
+	AnjutaPlugin* plugin = ANJUTA_PLUGIN(g_object_get_data (G_OBJECT(priv->view), "__plugin"));
+	
+	g_return_if_fail (plugin != NULL);
+
+	IAnjutaVcs* ivcs = anjuta_shell_get_interface (plugin->shell,
+												   IAnjutaVcs,
+												   NULL);
+	if (ivcs)
+	{	
+		VcsData* data = g_new0(VcsData, 1);
+		AnjutaAsyncNotify* notify = anjuta_async_notify_new();
+		data->ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (model),
+												path);
+		data->model = model;
+		
+		g_signal_connect_swapped (G_OBJECT (notify), "finished", 
+								  G_CALLBACK (file_model_free_vcs_data), data);
+
+		ianjuta_vcs_query_status(ivcs,
+								 file,
+								 file_model_vcs_status_callback,
+								 data,
+								 NULL,
+								 notify,
+								 NULL);
+	}						 
+	gtk_tree_path_free (path);	
+}
+
 static void
 file_model_update_file (FileModel* model,
 						GtkTreeIter* iter,
@@ -122,20 +284,27 @@ file_model_update_file (FileModel* model,
 {
 	GtkTreeStore* store = GTK_TREE_STORE(model);
 	gboolean is_dir = FALSE;
-	const gchar** icon_names;
+	gchar** icon_names;
 	GtkIconInfo* icon_info;
 	GIcon* icon;
-	GdkPixbuf* pixbuf;
+	GdkPixbuf* pixbuf = NULL;
 	gchar* display_name;
 	
 	icon = g_file_info_get_icon(file_info);
-	g_object_get (icon, "names", &icon_names, NULL);
-	icon_info = gtk_icon_theme_choose_icon (gtk_icon_theme_get_default(),
-											icon_names,
-											ICON_SIZE,
-											GTK_ICON_LOOKUP_GENERIC_FALLBACK);
-	pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
-	gtk_icon_info_free(icon_info);
+	if (icon)
+	{
+		g_object_get (icon, "names", &icon_names, NULL);
+		
+		if ((icon_info = gtk_icon_theme_choose_icon (gtk_icon_theme_get_default(),
+													 (const gchar **)icon_names,
+													 ICON_SIZE,
+													 GTK_ICON_LOOKUP_GENERIC_FALLBACK)))
+		{
+			pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+			gtk_icon_info_free(icon_info);
+		}
+		g_strfreev (icon_names);
+ 	}
 	
 	if (g_file_info_get_file_type(file_info) == G_FILE_TYPE_DIRECTORY)
 		is_dir = TRUE;
@@ -148,13 +317,18 @@ file_model_update_file (FileModel* model,
 						COLUMN_FILENAME, display_name,
 						COLUMN_FILE, file,
 						COLUMN_PIXBUF, pixbuf,
+						COLUMN_STATUS, ANJUTA_VCS_STATUS_NONE,
 						COLUMN_IS_DIR, is_dir,
 						COLUMN_SORT, g_file_info_get_sort_order(file_info),
 						-1);
+	
 	if (is_dir)
 		file_model_add_dummy(model, iter);
+	else
+		file_model_get_vcs_status (model, iter, file);
 	
-	g_object_unref (pixbuf);
+	if (pixbuf)
+		g_object_unref (pixbuf);
 	g_free(display_name);
 }
 
@@ -320,6 +494,7 @@ on_row_expanded_async (GObject* source_object,
 		GFile* file = g_file_get_child (dir, g_file_info_get_name(file_info));
 		file_model_add_file (data->model, &real_iter, file, file_info);
 		g_object_unref (file);
+		g_object_unref (file_info);
 	}
 	/* Remove dummy node */
 	gtk_tree_model_iter_children (GTK_TREE_MODEL(model), &dummy, &real_iter);
@@ -524,8 +699,9 @@ file_model_new (GtkTreeView* tree_view, const gchar* base_uri)
 	GObject* model =
 		g_object_new (FILE_TYPE_MODEL, "base_uri", base_uri, NULL);
 	GType types[N_COLUMNS] = {GDK_TYPE_PIXBUF, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_OBJECT,
+		G_TYPE_STRING, G_TYPE_UINT, G_TYPE_OBJECT,
 		G_TYPE_BOOLEAN, G_TYPE_INT};
+	FileModelPrivate* priv = FILE_MODEL_GET_PRIVATE(model);
 	
 	g_signal_connect (G_OBJECT (tree_view), "row-collapsed", 
 					  G_CALLBACK (file_model_row_collapsed), model);
@@ -535,6 +711,8 @@ file_model_new (GtkTreeView* tree_view, const gchar* base_uri)
 	gtk_tree_store_set_column_types (GTK_TREE_STORE (model), N_COLUMNS,
 									 types);
 	
+	priv->view = tree_view;
+	
 	return FILE_MODEL(model);
 }
 
@@ -553,9 +731,11 @@ file_model_refresh (FileModel* model)
 								  G_FILE_QUERY_INFO_NONE, NULL, NULL);
 	
 	if (!base_info)
-		return;
-	
-	file_model_add_file (model, NULL, base, base_info);
+		goto out;
+ 	
+ 	file_model_add_file (model, NULL, base, base_info);
+	g_object_unref (base_info);
+out:
 	g_object_unref (base);
 }
 
