@@ -20,7 +20,6 @@
 
 #include <config.h>
 
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
@@ -171,7 +170,7 @@ on_document_destroy (GtkWidget* document, GladePlugin *plugin)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	DEBUG_PRINT(__FUNCTION__);
+	DEBUG_PRINT ("%s", "Destroying Document");
 	
 	if (plugin->priv->destroying)
 	{
@@ -325,12 +324,14 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 			if (project->path)
 #endif
 			{
-				uri = gnome_vfs_get_uri_from_local_path (
+				GFile *file = g_file_new_for_path (
 #if (GLADEUI_VERSION >= 330)
 					ppath);
 #else
 					project->path);
 #endif
+				uri = g_file_get_uri (file);
+				g_object_unref (file);
 				if (uri)
 				{
 					/ * FIXME only log file if it's still open in docman * /
@@ -408,7 +409,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	GtkListStore *store;
 	GtkCellRenderer *renderer;
 	
-	DEBUG_PRINT ("GladePlugin: Activating Glade plugin...");
+	DEBUG_PRINT ("%s", "GladePlugin: Activating Glade plugin...");
 	
 	glade_plugin = ANJUTA_PLUGIN_GLADE (plugin);
 	
@@ -523,7 +524,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	
 	priv = ANJUTA_PLUGIN_GLADE (plugin)->priv;
 		
-	DEBUG_PRINT ("GladePlugin: Dectivating Glade plugin...");
+	DEBUG_PRINT ("%s", "GladePlugin: Dectivating Glade plugin...");
 	
 	/* Disconnect signals */
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
@@ -591,7 +592,7 @@ glade_plugin_instance_init (GObject *obj)
 	priv = plugin->priv;
 	priv->destroying = FALSE;
 	
-	DEBUG_PRINT ("Intializing Glade plugin");
+	DEBUG_PRINT ("%s", "Intializing Glade plugin");
 }
 
 static void
