@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002, 2003  Sebastian Rittau <srittau@jroger.in-berlin.de>
- * $Id: egg-datetime.c 2702 2006-11-29 13:41:43Z naba $
+ * $Id: egg-datetime.c 4610 2009-01-19 17:17:01Z jhs $
  *
  * Based on GnomeDateEdit by Miguel de Icaza.
  *
@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 /****************************************************************/
 /* This file is modified for the use with gtodo. 		*/
@@ -249,10 +249,10 @@ static void	 update_time_label		(EggDateTime *edt);
 static GtkHBoxClass *parent_class = NULL;
 
 
-	GtkType
+GType
 egg_datetime_get_type (void)
 {
-	static GtkType datetime_type = 0;
+	static GType datetime_type = 0;
 
 	if (!datetime_type) {
 		static const GTypeInfo datetime_info = {
@@ -334,7 +334,8 @@ egg_datetime_class_init (EggDateTimeClass *klass)
 			0, 59, 0,
 			G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
 	g_object_class_install_property (o_class, ARG_MINUTE, pspec);
-	pspec = g_param_spec_uint ("second",
+	/* second (time) not 2nd */
+  pspec = g_param_spec_uint ("second",
 			_("Second"),
 			_("Displayed second"),
 			0, 59, 0,
@@ -604,7 +605,7 @@ egg_datetime_set_property (GObject	*object,
 			priv->year = g_value_get_uint (value);
 			break;
 		case ARG_MONTH:
-			priv->minute = g_value_get_uint (value);
+			priv->month = g_value_get_uint (value);
 			break;
 		case ARG_DAY:
 			priv->day = g_value_get_uint (value);
