@@ -7,6 +7,10 @@
 #include <time.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
+#include <libxslt/xslt.h>
+#include <libxslt/xsltInternals.h>
+#include <libxslt/transform.h>
+#include <libxslt/xsltutils.h>
 #include <libanjuta/anjuta-debug.h>
 #include "libgtodo.h"
 
@@ -759,32 +763,7 @@ int gtodo_client_save_xml_to_file(GTodoClient *cl, GFile *file, GError **error)
 	/* xmlIndentTreeOutput = 1; */
 	xmlKeepBlanksDefault(0);
 	xmlDocDumpFormatMemory(cl->gtodo_doc, &buffer, &size, TRUE);
-	/* dirty trick to get the whole crap to work on ftp */
-#if 0
-	/* Check if necessary with GIO */
-	if(!strncmp(file, "ftp://", MIN(strlen(file),6)))
-	{
-		GnomeVFSURI *uri = gnome_vfs_uri_new(file);
-		if(uri != NULL && gnome_vfs_uri_exists(uri))
-		{
-			/* stupid hack to make everything work.. darn ftp */
-			if(debug)g_print("trying to unlink the file\n");
-			if(gnome_vfs_unlink(file) != GNOME_VFS_OK)
-			{      
-				if(debug)g_print("Failed to delete\n");
-				g_set_error(&tmp_error,LIBGTODO_ERROR,LIBGTODO_ERROR_GENERIC,_("Failed to delete %s."),file);	
-				g_propagate_error(error, tmp_error);
-				return TRUE;	
-			}
-			else
-			{
-				if(debug)g_print("file unlinked\n");
-			}
-		}
-		gnome_vfs_uri_unref(uri);
-	}
-#endif
-	/* open the file for writing */
+
 	if (!g_file_replace_contents (file, 
 			(char *)buffer, size, 
 			NULL, FALSE, G_FILE_CREATE_NONE, 
@@ -1558,3 +1537,44 @@ gboolean gtodo_client_get_read_only(GTodoClient *cl)
 	if(cl == NULL) return FALSE;
 	return cl->read_only;	
 }
+
+
+gboolean 
+gtodo_client_export(GTodoClient *source, GFile *dest, const gchar *path_to_xsl, gchar **params, GError **error)
+{
+	xsltStylesheetPtr cur;
+	xmlChar *string;
+	xmlDocPtr res;
+	int length;
+	GError *err;
+
+	g_return_val_if_fail(path_to_xsl != NULL, FALSE);
+
+	cur= xsltParseStylesheetFile(BAD_CAST (path_to_xsl));
+
+	if (params == NULL)
+	{
+		res = xsltApplyStylesheet(cur, source->gtodo_doc, NULL);
+	}
+	else
+	{
+		res = xsltApplyStylesheet(cur, source->gtodo_doc, (const char **)params);
+	}
+
+	xsltSaveResultToString (&string, &length, res, cur);
+
+	if (!g_file_replace_contents (dest, (char *)string, length, NULL, FALSE,
+			G_FILE_CREATE_NONE, NULL, NULL, &err))
+	{
+		DEBUG_PRINT ("Error exporting file: %s", 
+				err->message);
+		g_propagate_error (error, err);
+	}
+
+	xmlFree (string);
+	xsltFreeStylesheet (cur);
+	xmlFreeDoc (res);
+	xsltCleanupGlobals ();
+
+	return TRUE;
+}
