@@ -19,8 +19,6 @@
 */
 
 #include <config.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-file-savable.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
@@ -28,12 +26,12 @@
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-file-manager.h>
 #include <libanjuta/interfaces/ianjuta-builder.h>
+#include <libanjuta/interfaces/ianjuta-project-backend.h>
 #include <libanjuta/anjuta-profile-manager.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-status.h>
 
-#include <gbf/gbf-project-util.h>
-#include <gbf/gbf-backend.h>
+#include "gbf-project-util.h"
 
 #include "plugin.h"
 
@@ -86,18 +84,31 @@ update_title (ProjectManagerPlugin* plugin, const gchar *project_uri)
 	status = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell, NULL);
 	if (project_uri)
 	{
-		gchar* uri_basename;
-		gchar* unescape_basename;
-		gchar* ext;
-		
-		uri_basename = g_path_get_basename (project_uri);
-		unescape_basename = gnome_vfs_unescape_string (uri_basename, "");
-		ext = strrchr (unescape_basename, '.');
-		if (ext)
-			*ext = '\0';
-		anjuta_status_set_title (status, unescape_basename);
-		g_free (unescape_basename);
-		g_free (uri_basename);
+		GFile *file;
+		GFileInfo *file_info;
+
+		file = g_file_new_for_uri (project_uri);
+		file_info = g_file_query_info (file,
+			G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+			G_FILE_QUERY_INFO_NONE,
+			NULL,
+			NULL);
+		if (file_info)
+		{
+			gchar *dispname;
+			gchar *ext;
+			
+			dispname = g_strdup (
+				g_file_info_get_display_name (file_info));
+			ext = strrchr (dispname, '.');	
+			if (ext)
+				*ext = '\0';
+			anjuta_status_set_title (status, dispname);
+			g_free (dispname);
+			g_object_unref (file_info);
+		}
+
+		g_object_unref (file);
 	}
 	else
 	{
@@ -108,26 +119,18 @@ update_title (ProjectManagerPlugin* plugin, const gchar *project_uri)
 static gchar*
 get_session_dir (ProjectManagerPlugin *plugin)
 {
-	GnomeVFSURI *vfs_uri;
 	gchar *session_dir = NULL;
+	gchar *local_dir;
 	
 	g_return_val_if_fail (plugin->project_root_uri, NULL);
 	
-	vfs_uri = gnome_vfs_uri_new (plugin->project_root_uri);
-	if (vfs_uri && gnome_vfs_uri_is_local (vfs_uri))
+	local_dir = anjuta_util_get_local_path_from_uri (plugin->project_root_uri);
+	if (local_dir)
 	{
-		gchar *local_dir;
-		
-		local_dir = gnome_vfs_get_local_path_from_uri (plugin->project_root_uri);
-		if (local_dir)
-		{
-			session_dir = g_build_filename (local_dir, ".anjuta", "session",
-											NULL);
-		}
-		g_free (local_dir);
+		session_dir = g_build_filename (local_dir, ".anjuta", "session",
+										NULL);
 	}
-	if (vfs_uri)
-		gnome_vfs_uri_unref (vfs_uri);
+	g_free (local_dir);
 	
 	return session_dir;
 }
@@ -734,22 +737,27 @@ static void
 on_popup_add_to_project (GtkAction *action, ProjectManagerPlugin *plugin)
 {
 	GtkWindow *win;
-	GnomeVFSFileInfo info;
-	GnomeVFSResult res;
+	GFile *file;
+	GFileInfo *file_info;
 	gchar *parent_directory, *filename;
+	GError *error = NULL;
 	
 	win = get_plugin_parent_window (plugin);
-	res = gnome_vfs_get_file_info (plugin->fm_current_uri, &info,
-								   GNOME_VFS_FILE_INFO_DEFAULT |
-								   GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
-	if (res == GNOME_VFS_OK)
+
+	file = g_file_new_for_uri (plugin->fm_current_uri);
+	file_info = g_file_query_info (file,
+	                               G_FILE_ATTRIBUTE_STANDARD_TYPE,
+								   G_FILE_QUERY_INFO_NONE,
+								   NULL,
+								   &error);
+	if (file_info != NULL)
 	{
 		parent_directory = g_path_get_dirname (plugin->fm_current_uri);
 		if (!parent_directory)
 			parent_directory = g_strdup ("");
 		
 		filename = g_path_get_basename (plugin->fm_current_uri);
-		if (info.type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+		if (g_file_info_get_file_type (file_info) == G_FILE_TYPE_DIRECTORY)
 		{
 			gchar *group_id =
 			ianjuta_project_manager_add_group (IANJUTA_PROJECT_MANAGER (plugin),
@@ -767,20 +775,15 @@ on_popup_add_to_project (GtkAction *action, ProjectManagerPlugin *plugin)
 													NULL);
 			g_free(source_id);
 		}
+		g_object_unref (file_info);
 		g_free (filename);
 		g_free (parent_directory);
 	}
 	else
 	{
-		const gchar *mesg;
-		
-		if (res != GNOME_VFS_OK)
-			mesg = gnome_vfs_result_to_string (res);
-		else
-			mesg = _("The file you selected is a link and can't be added to the project");
-		anjuta_util_dialog_error (win,
-								  _("Failed to retrieve URI info of %s: %s"),
-								  plugin->fm_current_uri, mesg);
+		anjuta_util_dialog_error (win, _("Failed to retrieve URI info of %s: %s"),
+					  plugin->fm_current_uri, error->message);
+		g_error_free (error);
 	}
 }
 
@@ -1177,28 +1180,41 @@ value_removed_current_editor (AnjutaPlugin *plugin,
 static void
 project_manager_load_gbf (ProjectManagerPlugin *pm_plugin)
 {
+	AnjutaPluginManager *plugin_manager;
 	AnjutaStatus *status;
 	gchar *dirname;
 	const gchar *root_uri;
-	GSList *l;
 	GError *error = NULL;
-	GbfBackend *backend = NULL;
+	GList *descs = NULL;
+	GList *desc;
 	
 	root_uri = pm_plugin->project_root_uri;
 	
-	dirname = gnome_vfs_get_local_path_from_uri (root_uri);
+	dirname = anjuta_util_get_local_path_from_uri (root_uri);
 	
 	g_return_if_fail (dirname != NULL);
 	
 	if (pm_plugin->project != NULL)
 			g_object_unref (pm_plugin->project);
 	
-	DEBUG_PRINT ("initializing gbf backend...\n");
-	gbf_backend_init ();
-	for (l = gbf_backend_get_backends (); l; l = l->next) {
-		backend = l->data;
+	DEBUG_PRINT ("loading gbf backend...\n");
+	plugin_manager = anjuta_shell_get_plugin_manager (ANJUTA_PLUGIN(pm_plugin)->shell, NULL);
+	descs = anjuta_plugin_manager_query (plugin_manager,
+										 "Anjuta Plugin",
+										 "Interfaces",
+										 "IAnjutaProjectBackend",
+										 NULL);
+	for (desc = g_list_first (descs); desc != NULL; desc = g_list_next (desc)) {
+		AnjutaPluginDescription *backend;
+		IAnjutaProjectBackend *plugin;
+		gchar *location = NULL;
 		
-		pm_plugin->project = gbf_backend_new_project (backend->id);
+		backend = (AnjutaPluginDescription *)desc->data;
+		anjuta_plugin_description_get_string (backend, "Anjuta Plugin", "Location", &location);
+		plugin = (IAnjutaProjectBackend *)anjuta_plugin_manager_get_plugin_by_id (plugin_manager, location);
+		g_free (location);
+			
+		pm_plugin->project = ianjuta_project_backend_new_project (plugin, NULL);
 		if (pm_plugin->project)
 		{
 			if (gbf_project_probe (pm_plugin->project, dirname, NULL))
@@ -1213,10 +1229,11 @@ project_manager_load_gbf (ProjectManagerPlugin *pm_plugin)
 		if (!strcmp (backend->id, "gbf-am:GbfAmProject"))
 			break;
 		*/
-		backend = NULL;
+		plugin = NULL;
 	}
+	g_list_free (descs);
 	
-	if (!backend)
+	if (!pm_plugin->project)
 	{
 		/* FIXME: Set err */
 		g_warning ("no backend available for this project\n");
@@ -1224,7 +1241,7 @@ project_manager_load_gbf (ProjectManagerPlugin *pm_plugin)
 		return;
 	}
 	
-	DEBUG_PRINT ("Creating new gbf project\n");
+	DEBUG_PRINT ("%s", "Creating new gbf project\n");
 	
 	/* pm_plugin->project = gbf_backend_new_project (backend->id); */
 	if (!pm_plugin->project)
@@ -1374,7 +1391,7 @@ on_profile_scoped (AnjutaProfileManager *profile_manager,
 	if (strcmp (anjuta_profile_get_name (profile), PROJECT_PROFILE_NAME) != 0)
 		return;
 	
-	DEBUG_PRINT ("Project profile loaded; Restoring project session");
+	DEBUG_PRINT ("%s", "Project profile loaded; Restoring project session");
 	
 	/* Load gbf project */
 	project_manager_load_gbf (plugin);
@@ -1414,7 +1431,7 @@ on_profile_descoped (AnjutaProfileManager *profile_manager,
 	if (strcmp (anjuta_profile_get_name (profile), PROJECT_PROFILE_NAME) != 0)
 		return;
 	
-	DEBUG_PRINT ("Project profile descoped; Saving project session");
+	DEBUG_PRINT ("%s", "Project profile descoped; Saving project session");
 	
 	/* Save current project session */
 	g_return_if_fail (plugin->project_root_uri != NULL);
@@ -1465,7 +1482,7 @@ project_manager_plugin_activate_plugin (AnjutaPlugin *plugin)
 	/* GladeXML *gxml; */
 	ProjectManagerPlugin *pm_plugin;
 	
-	DEBUG_PRINT ("ProjectManagerPlugin: Activating Project Manager plugin...");
+	DEBUG_PRINT ("ProjectManagerPlugin: Activating Project Manager plugin %p...", plugin);
 	
 	if (!initialized)
 		register_stock_icons (plugin);
@@ -1577,6 +1594,7 @@ project_manager_plugin_deactivate_plugin (AnjutaPlugin *plugin)
 	ProjectManagerPlugin *pm_plugin;
 	pm_plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (plugin);
 
+	DEBUG_PRINT ("ProjectManagerPlugin: Deactivate Project Manager plugin...");
 	if (pm_plugin->close_project_idle > -1)
 	{
 		g_source_remove (pm_plugin->close_project_idle);
@@ -1666,12 +1684,26 @@ project_manager_plugin_class_init (GObjectClass *klass)
 
 /* IAnjutaProjectManager implementation */
 
-static GnomeVFSFileType
+static GFileType
 get_uri_vfs_type (const gchar *uri)
 {
-	GnomeVFSFileInfo info;
-	gnome_vfs_get_file_info (uri, &info, 0);
-	return info.type;
+	GFileType retval = G_FILE_TYPE_UNKNOWN;
+	GFile *file;
+	GFileInfo *file_info;
+
+	file = g_file_new_for_uri (uri);
+	file_info = g_file_query_info (file,
+		G_FILE_ATTRIBUTE_STANDARD_TYPE,
+		G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+		NULL, NULL);
+	if (file_info)
+	{
+		retval = g_file_info_get_file_type (file_info);
+		g_object_unref (file_info);
+	}
+
+	g_object_unref (file);
+	return retval;
 }
 
 static gboolean
@@ -1699,7 +1731,7 @@ get_element_uri_from_id (ProjectManagerPlugin *plugin, const gchar *id, const gc
 {
 	gchar *path, *ptr;
 	gchar *uri;
-	const gchar *project_root;
+	const gchar *project_root = NULL;
 	
 	if (!id)
 		return NULL;
@@ -1708,18 +1740,28 @@ get_element_uri_from_id (ProjectManagerPlugin *plugin, const gchar *id, const gc
 	ptr = strrchr (path, ':');
 	if (ptr)
 	{
+		*ptr = '\0';
 		if (ptr[1] == '/')
 		{
 			 /* ID is source ID, extract source uri */
-			ptr = strrchr (ptr, ':');
-			return g_strdup (ptr+1);
+			uri = strrchr (path, ':');		/* keep uri scheme */
+			*ptr = ':';
+			return g_strdup (uri+1);
 		}
-		*ptr = '\0';
 	}
 	
 	anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell,
 					  root, G_TYPE_STRING,
 					  &project_root, NULL);
+	if (project_root == NULL)
+	{
+		/* Perhaps missing build URI, use project URI instead */
+		anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell,
+					  IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
+					  G_TYPE_STRING,
+					  &project_root,
+					  NULL);
+	}
 	uri = g_build_filename (project_root, path, NULL);
 	/* DEBUG_PRINT ("Converting id: %s to %s", id, uri); */
 	g_free (path);
@@ -1734,6 +1776,15 @@ get_element_relative_path (ProjectManagerPlugin *plugin, const gchar *uri, const
 	anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell,
 					  root, G_TYPE_STRING,
 					  &project_root, NULL);
+	if (project_root == NULL)
+	{
+		/* Perhaps missing build URI, use project URI instead */
+		anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell,
+					  IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
+					  G_TYPE_STRING,
+					  &project_root,
+					  NULL);
+	}
 	if (project_root)
 	{
 		if (uri[0] != '/')
@@ -1806,7 +1857,7 @@ get_element_id_from_uri (ProjectManagerPlugin *plugin, const gchar *uri)
 		id = g_strdup (target->id);
 		gbf_project_target_free (target);
 	}
-	else if (get_uri_vfs_type (uri) | GNOME_VFS_FILE_TYPE_DIRECTORY)
+	else if (get_uri_vfs_type (uri) | G_FILE_TYPE_DIRECTORY)
 	{
 		id = g_strconcat (get_element_relative_path (plugin, uri, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI), "/", NULL);
 	}
@@ -1822,7 +1873,7 @@ iproject_manager_get_element_type (IAnjutaProjectManager *project_manager,
 								   const gchar *element_uri,
 								   GError **err)
 {
-	GnomeVFSFileType ftype;
+	GFileType ftype;
 	ProjectManagerPlugin *plugin;
 	
 	g_return_val_if_fail (ANJUTA_IS_PLUGIN (project_manager),
@@ -1835,7 +1886,7 @@ iproject_manager_get_element_type (IAnjutaProjectManager *project_manager,
 						  IANJUTA_PROJECT_MANAGER_UNKNOWN);
 	
 	ftype = get_uri_vfs_type (element_uri);
-	if (ftype | GNOME_VFS_FILE_TYPE_DIRECTORY)
+	if (ftype | G_FILE_TYPE_DIRECTORY)
 	{
 		return IANJUTA_PROJECT_MANAGER_GROUP;
 	}
@@ -1845,7 +1896,7 @@ iproject_manager_get_element_type (IAnjutaProjectManager *project_manager,
 	{
 		return IANJUTA_PROJECT_MANAGER_TARGET;
 	}
-	else if (ftype | GNOME_VFS_FILE_TYPE_REGULAR)
+	else if (ftype | G_FILE_TYPE_REGULAR)
 	{
 		return IANJUTA_PROJECT_MANAGER_SOURCE;
 	}
@@ -2151,7 +2202,7 @@ iproject_manager_add_source (IAnjutaProjectManager *project_manager,
 {
 	ProjectManagerPlugin *plugin;
 	IAnjutaProjectManagerElementType default_location_type;
-	gchar *location_id;
+	gchar *location_id = NULL;
 	gchar* source_id;
 	gchar* source_uri;
 	
@@ -2161,10 +2212,17 @@ iproject_manager_add_source (IAnjutaProjectManager *project_manager,
 	g_return_val_if_fail (GBF_IS_PROJECT (plugin->project), FALSE);
 
 	update_operation_begin (plugin);
-	default_location_type =
-		ianjuta_project_manager_get_element_type (project_manager,
-												  default_location_uri, NULL);
-	location_id = get_element_id_from_uri (plugin, default_location_uri);
+	if (default_location_uri == NULL)
+	{
+		default_location_type = IANJUTA_PROJECT_MANAGER_UNKNOWN;
+	}
+	else
+	{
+		default_location_type =
+			ianjuta_project_manager_get_element_type (project_manager,
+													  default_location_uri, NULL);
+		location_id = get_element_id_from_uri (plugin, default_location_uri);
+	}
 	if (default_location_type == IANJUTA_PROJECT_MANAGER_GROUP)
 	{
 		source_id = gbf_project_util_add_source (plugin->model,
@@ -2202,7 +2260,7 @@ iproject_manager_add_source_multi (IAnjutaProjectManager *project_manager,
 {
 	ProjectManagerPlugin *plugin;
 	IAnjutaProjectManagerElementType default_location_type;
-	gchar *location_id;
+	gchar *location_id = NULL;
 	GList* source_ids;
 	GList* source_uris = NULL;
 	
@@ -2212,10 +2270,17 @@ iproject_manager_add_source_multi (IAnjutaProjectManager *project_manager,
 	g_return_val_if_fail (GBF_IS_PROJECT (plugin->project), FALSE);
 
 	update_operation_begin (plugin);
-	default_location_type =
-		ianjuta_project_manager_get_element_type (project_manager,
-												  default_location_uri, NULL);
-	location_id = get_element_id_from_uri (plugin, default_location_uri);
+	if (default_location_uri == NULL)
+	{
+		default_location_type = IANJUTA_PROJECT_MANAGER_UNKNOWN;
+	}
+	else
+	{
+		default_location_type =
+			ianjuta_project_manager_get_element_type (project_manager,
+													  default_location_uri, NULL);
+		location_id = get_element_id_from_uri (plugin, default_location_uri);
+	}
 	if (default_location_type == IANJUTA_PROJECT_MANAGER_GROUP)
 	{
 		source_ids = gbf_project_util_add_source_multi (plugin->model,
@@ -2332,6 +2397,9 @@ iproject_manager_get_packages (IAnjutaProjectManager *project_manager, GError **
 	
 	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (G_OBJECT (project_manager));
 	
+	/* Check if a current project is opened */
+	if (plugin->project == NULL) return NULL;
+	
 	modules = gbf_project_get_config_modules (plugin->project, NULL);
 	for (node = modules; node != NULL; node = g_list_next (node))
 	{
@@ -2370,23 +2438,27 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 	AnjutaProfileManager *profile_manager;
 	AnjutaPluginManager *plugin_manager;
 	AnjutaStatus *status;
-	gchar *dirname, *dirname_tmp, *vfs_dir;
-	gchar *session_profile, *profile_name;
+	gchar *session_profile_path, *profile_name;
+	GFile *session_profile;
+	GFile *default_profile;
+	GFile *project_root;
+	GFile *tmp;
 	ProjectManagerPlugin *plugin;
 	GError *error = NULL;
-	gchar* uri = g_file_get_uri (file);
-	GnomeVFSURI* vfs_uri;
-	
+
 	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (ifile);
 	
 	/* If there is already a project loaded, load in separate anjuta window */
 	if (plugin->project_root_uri)
 	{
+		gchar *uri = g_file_get_uri (file);
 		gchar *quoted_uri = g_shell_quote (uri);
 		gchar *cmd = g_strconcat ("anjuta --no-splash --no-client ", quoted_uri, NULL);
 		g_free (quoted_uri);
 		anjuta_util_execute_shell (NULL, cmd);
 		g_free (cmd);
+		g_free (uri);
+		
 		return;
 	}
 	
@@ -2401,64 +2473,67 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 	profile = anjuta_profile_new (PROJECT_PROFILE_NAME, plugin_manager);
 	
 	/* System default profile */
-	anjuta_profile_add_plugins_from_xml (profile, DEFAULT_PROFILE,
+	default_profile = g_file_new_for_uri (DEFAULT_PROFILE);
+	anjuta_profile_add_plugins_from_xml (profile, default_profile,
 										 TRUE, &error);
+	profile_name = g_file_get_basename (default_profile);
+	g_object_unref (default_profile);
 	if (error)
 	{
-		anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (ifile)->shell),
-								  "%s", error->message);
-		g_error_free (error);
-		error = NULL;
+		g_propagate_error (e, error);
+		g_free (profile_name);
+		g_object_unref (profile);
+		
+		return;
 	}
 	
 	/* Project default profile */
-	anjuta_profile_add_plugins_from_xml (profile, uri, TRUE, &error);
+	anjuta_profile_add_plugins_from_xml (profile, file, TRUE, &error);
 	if (error)
 	{
-		anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (ifile)->shell),
-								  "%s", error->message);
-		g_error_free (error);
-		error = NULL;
+		g_propagate_error (e, error);
+	
+		g_free (profile_name);
+		g_object_unref (profile);
+
+		return;
 	}
 	
 	/* Project session profile */
-	vfs_uri = gnome_vfs_uri_new (uri);
+	project_root = g_file_get_parent (file);
+	tmp = g_file_get_child (project_root, ".anjuta");
+	session_profile = g_file_get_child (tmp, profile_name);
+	g_object_unref (tmp);
+	g_free (profile_name);
 	
-	dirname_tmp = gnome_vfs_uri_extract_dirname (vfs_uri);
-	dirname = gnome_vfs_unescape_string (dirname_tmp, "");
-	g_free (dirname_tmp);
-	
-	profile_name = g_path_get_basename (DEFAULT_PROFILE);
-	gnome_vfs_uri_unref (vfs_uri);
-	
-	session_profile = g_build_filename (dirname, ".anjuta",
-										profile_name, NULL);
-	DEBUG_PRINT ("Loading project session profile: %s", session_profile);
-
-	if (g_file_test (session_profile, G_FILE_TEST_EXISTS))
+	session_profile_path = g_file_get_path (session_profile);
+	DEBUG_PRINT ("Loading project session profile: %s", session_profile_path);
+	if (g_file_query_exists (session_profile, NULL))
 	{
 		anjuta_profile_add_plugins_from_xml (profile, session_profile,
 											 FALSE, &error);
 		if (error)
 		{
-			anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (ifile)->shell),
-									  "%s", error->message);
-			g_error_free (error);
-			error = NULL;
+			g_propagate_error (e, error);
+		
+			g_free (session_profile_path);
+			g_object_unref (project_root);
+			g_object_unref (profile);
+			g_object_unref (session_profile);
+			
+			return;
 		}
 	}
-	anjuta_profile_set_sync_uri (profile, session_profile); 
-	g_free (session_profile);
-	g_free (profile_name);
+	anjuta_profile_set_sync_file (profile, session_profile); 
+	g_free (session_profile_path);
 	
 	/* Set project uri */
 	g_free (plugin->project_root_uri);
 	g_free (plugin->project_uri);
 	
-	vfs_dir = gnome_vfs_get_uri_from_local_path (dirname);
-	plugin->project_uri = g_strdup (uri);
-	plugin->project_root_uri = vfs_dir;
-	g_free (dirname);
+	plugin->project_uri = g_file_get_uri (file);
+	plugin->project_root_uri = g_file_get_uri (project_root);
+	g_object_unref (project_root);
 	
 	/* Load profile */
 	anjuta_profile_manager_push (profile_manager, profile, &error);
@@ -2471,11 +2546,10 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 	}
 	
 	anjuta_status_progress_tick (status, NULL,
-								 _("Loaded Project... Initializing"));
+								 _("Initializing Project..."));
 	update_ui (plugin);
 
-	anjuta_status_progress_tick (status, NULL, _("Loaded Project..."));
-	g_free (uri);
+	anjuta_status_progress_tick (status, NULL, _("Project Loaded"));
 }
 
 static GFile*
