@@ -74,7 +74,8 @@ typedef enum
 	TASK_BUFFER_UPDATE,
 	TASK_ELEMENT_ADDED,
 	TASK_OFFLINE_CHANGES,
-	TASK_PROJECT_UPDATE
+	TASK_PROJECT_UPDATE,
+	TASK_FILE_UPDATE
 } ProcTask;
 
 static unsigned int signals[LAST_SIGNAL] = { 0 };
@@ -113,57 +114,119 @@ goto_file_line (AnjutaPlugin *plugin, const gchar *filename, gint lineno)
 	g_object_unref (file);
 }
 
+/* Find an implementation (if impl == TRUE) or declaration (if impl == FALSE)
+ * from the given symbol iterator.
+ * If current_document != NULL it prefers matches from the currently open document
+ */
+static gchar *
+find_file_line (SymbolDBEngineIterator *iterator, gboolean impl, const gchar *current_document,
+				gint *line)
+{
+	gchar *path = NULL;
+	gint _line = -1;
+	
+	do
+	{
+		const gchar *symbol_kind;
+		gboolean is_decl;		
+		SymbolDBEngineIteratorNode *iter_node =
+			SYMBOL_DB_ENGINE_ITERATOR_NODE (iterator);
+		
+		if (iter_node == NULL)
+		{
+			/* not found or some error occurred */
+			break;  
+		}
+		
+		symbol_kind = symbol_db_engine_iterator_node_get_symbol_extra_string (
+																			  iter_node, SYMINFO_KIND);				
+		is_decl = g_strcmp0 (symbol_kind, "prototype") == 0 || 
+			g_strcmp0 (symbol_kind, "interface") == 0;
+		
+		if (is_decl == !impl) 
+		{
+			const gchar *_path;
+			_path = symbol_db_engine_iterator_node_get_symbol_extra_string (iter_node,
+																			SYMINFO_FILE_PATH);
+			/* if the path matches the current document we return immidiately */
+			if (!current_document || g_strcmp0 (_path, current_document) == 0)
+			{
+				*line = symbol_db_engine_iterator_node_get_symbol_file_pos (iter_node);
+				g_free (path);
+				
+				return g_strdup (_path);
+			}
+			/* we store the first match incase there is no match against the current document */
+			else if (_line == -1)
+			{
+				path = g_strdup (_path);
+				_line = symbol_db_engine_iterator_node_get_symbol_file_pos (iter_node);
+			}
+		}
+	} while (symbol_db_engine_iterator_move_next (iterator) == TRUE);
+	
+	if (_line != -1)
+		*line = _line;
+	
+	return path;	
+}
+
 static void
-goto_file_tag (SymbolDBPlugin *sdb_plugin, const char *word,
-			   gboolean prefer_definition)
+goto_file_tag (SymbolDBPlugin *sdb_plugin, const gchar *word,
+			   gboolean prefer_implementation)
 {
 	SymbolDBEngineIterator *iterator;	
+	gchar *path = NULL;
+	gint line;
+	
 	iterator = symbol_db_engine_find_symbol_by_name_pattern (sdb_plugin->sdbe_project, 
 															 word,
+															 TRUE,
 															 SYMINFO_SIMPLE |
-											   				 SYMINFO_KIND |
+															 SYMINFO_KIND |
 															 SYMINFO_FILE_PATH);
-	do {
-		const gchar *symbol_kind;
-		SymbolDBEngineIteratorNode *iter_node; 
-		iter_node = SYMBOL_DB_ENGINE_ITERATOR_NODE (iterator);			
-
-		/* not found or some error occurred */
-		if (iter_node == NULL)
-			break;
-
-		symbol_kind = symbol_db_engine_iterator_node_get_symbol_extra_string (
-					iter_node, SYMINFO_KIND);				
+	
+	if (iterator != NULL && symbol_db_engine_iterator_get_n_items (iterator) > 0)
+	{
+		gchar *current_document = NULL;
+		/* FIXME: namespaces are not handled here, but they should. */
 		
-		if (prefer_definition == FALSE && g_strcmp0 (symbol_kind, "prototype") == 0)
+		if (IANJUTA_IS_FILE (sdb_plugin->current_editor))
 		{
-			gint line = 
-				symbol_db_engine_iterator_node_get_symbol_file_pos (iter_node);
-			const gchar* file = 
-				symbol_db_engine_iterator_node_get_symbol_extra_string (iter_node,
-													SYMINFO_FILE_PATH);
-			goto_file_line (ANJUTA_PLUGIN (sdb_plugin), file, line);
-			break;
+			GFile *file;
+			
+			if ((file = ianjuta_file_get_file (IANJUTA_FILE (sdb_plugin->current_editor),
+											   NULL)))
+			{
+				current_document = g_file_get_path (file);
+				g_object_unref (file);
+			}
 		}
-		else if (prefer_definition == TRUE && g_strcmp0 (symbol_kind, "function") == 0)
+		
+		path = find_file_line (iterator, prefer_implementation, current_document, &line);
+		if (!path)
 		{
-			gint line = 
-				symbol_db_engine_iterator_node_get_symbol_file_pos (iter_node);
-			const gchar* file = 
-				symbol_db_engine_iterator_node_get_symbol_extra_string (iter_node,
-													SYMINFO_FILE_PATH);
-			goto_file_line (ANJUTA_PLUGIN (sdb_plugin), file, line);
-			break;
+			/* reset iterator */
+			symbol_db_engine_iterator_first (iterator);   
+			path = find_file_line (iterator, !prefer_implementation, current_document,
+								   &line);
 		}
-
-	} while (symbol_db_engine_iterator_move_next (iterator) == TRUE);	
+		
+		if (path)
+		{
+			goto_file_line (ANJUTA_PLUGIN (sdb_plugin), path, line);
+			g_free (path);
+		}
+		
+		g_free (current_document);
+	}
 	
 	if (iterator)
 		g_object_unref (iterator);
 }
 
 static void
-on_goto_file_tag_def_activate (GtkAction *action, SymbolDBPlugin *sdb_plugin)
+on_goto_file_tag_impl_activate (GtkAction *action, SymbolDBPlugin *sdb_plugin)
 {
 	IAnjutaEditor *ed;
 	gchar *word;
@@ -201,14 +264,6 @@ on_goto_file_tag_decl_activate (GtkAction *action, SymbolDBPlugin *sdb_plugin)
 static GtkActionEntry actions[] = 
 {
 	{ "ActionMenuGoto", NULL, N_("_Goto"), NULL, NULL, NULL},
-	{
-		"ActionSymbolDBGotoDef",
-		NULL,
-		N_("Tag _Definition"),
-		"<control>d",
-		N_("Goto symbol definition"),
-		G_CALLBACK (on_goto_file_tag_def_activate)
-	},
 	{
 		"ActionSymbolDBGotoDecl",
 		NULL,
@@ -216,7 +271,15 @@ static GtkActionEntry actions[] =
 		"<shift><control>d",
 		N_("Goto symbol declaration"),
 		G_CALLBACK (on_goto_file_tag_decl_activate)
-	}
+	},
+	{
+		"ActionSymbolDBGotoImpl",
+		NULL,
+		N_("Tag _Implementation"),
+		"<control>d",
+		N_("Goto symbol definition"),
+		G_CALLBACK (on_goto_file_tag_impl_activate)
+	}	
 };
 
 static void
@@ -275,8 +338,7 @@ on_editor_buffer_symbols_update_timeout (gpointer user_data)
 		return TRUE;
 	
 	seconds_elapsed = g_timer_elapsed (sdb_plugin->update_timer, NULL);
-	
-	/* DEBUG_PRINT ("seconds_elapsed  %f", seconds_elapsed ); */
+
 	if (seconds_elapsed < TIMEOUT_SECONDS_AFTER_LAST_TIP)
 		return TRUE;
 		
@@ -399,7 +461,6 @@ on_char_added (IAnjutaEditor *editor, IAnjutaIterable *position, gchar ch,
 		sdb_plugin->need_symbols_update = TRUE;
 }
 
-
 static void
 on_editor_saved (IAnjutaEditor *editor, GFile* file,
 				 SymbolDBPlugin *sdb_plugin)
@@ -408,6 +469,7 @@ on_editor_saved (IAnjutaEditor *editor, GFile* file,
 	gchar *local_filename;
 	gchar *saved_uri;
 	GPtrArray *files_array;
+	gint proc_id;
 	gint i;
 	
 	local_filename = g_file_get_path (file);
@@ -440,8 +502,15 @@ on_editor_saved (IAnjutaEditor *editor, GFile* file,
 		old_uri = NULL;
 
 	/* files_array will be freed once updating has taken place */
-	symbol_db_engine_update_files_symbols (sdb_plugin->sdbe_project, 
-		sdb_plugin->project_root_dir, files_array, TRUE);
+	proc_id = symbol_db_engine_update_files_symbols (sdb_plugin->sdbe_project, 
+						sdb_plugin->project_root_dir, files_array, TRUE);
+	if (proc_id > 0)
+	{		
+		/* add a task so that scan_end_manager can manage this */
+		g_tree_insert (sdb_plugin->proc_id_tree, GINT_TO_POINTER (proc_id),
+					   GINT_TO_POINTER (TASK_FILE_UPDATE));
+	}
+	
 	g_hash_table_insert (sdb_plugin->editor_connected, editor,
 						 g_strdup (saved_uri));
 
@@ -690,7 +759,8 @@ goto_global_tree_iter (SymbolDBPlugin *sdb_plugin, GtkTreeIter *iter)
 			SYMBOL_DB_VIEW (sdb_plugin->dbv_view_tree), sdb_plugin->sdbe_project,
 							iter, &line, &file) == FALSE)
 	{
-		g_warning ("goto_global_tree_iter (): error while trying to get file/line");
+		DEBUG_PRINT ("goto_global_tree_iter (): error while trying to get file/line. "
+					 "Maybe you clicked on Global/Var etc. node.");
 		return;
 	};
 	
@@ -1125,7 +1195,7 @@ on_project_single_file_scan_end (SymbolDBEngine *dbe, gpointer data)
 }
 
 static void
-project_import_scan_end (SymbolDBEngine *dbe, gint process_id, gpointer data)
+on_project_import_scan_end (SymbolDBEngine *dbe, gint process_id, gpointer data)
 {
 	SymbolDBPlugin *sdb_plugin;
 	GFile* file;
@@ -1437,7 +1507,10 @@ do_import_system_sources (SymbolDBPlugin *sdb_plugin)
 	}	
 }
 
-static void
+/**
+ * @return TRUE if a scan is in progress, FALSE elsewhere.
+ */
+static gboolean
 do_update_project_symbols (SymbolDBPlugin *sdb_plugin, const gchar *root_dir)
 {
 	gint proc_id;
@@ -1451,11 +1524,52 @@ do_update_project_symbols (SymbolDBPlugin *sdb_plugin, const gchar *root_dir)
 		/* insert the proc id associated within the task */
 		g_tree_insert (sdb_plugin->proc_id_tree, GINT_TO_POINTER (proc_id),
 					   GINT_TO_POINTER (TASK_PROJECT_UPDATE));
+		return TRUE;
+	}
+	
+	return FALSE;
+}
+
+/**
+ * Check the number of languages used by a project and then enable/disable the 
+ * global tab in case there's only C files.
+ */
+static void
+do_check_languages_count (SymbolDBPlugin *symbol_db)
+{
+	gint count;
+	
+	count = symbol_db_engine_get_languages_count (symbol_db->sdbe_project);
+	
+	/* is only C used? */
+	if (count == 1)
+	{
+		if (symbol_db_engine_is_language_used (symbol_db->sdbe_project, 
+											   "C") == TRUE)
+		{
+			/* hide the global tab and disable the receiving of signals */
+			symbol_db_view_recv_signals_from_engine (SYMBOL_DB_VIEW (
+													symbol_db->dbv_view_tree),
+													 symbol_db->sdbe_project,
+													 FALSE);
+			
+			gtk_widget_hide (symbol_db->scrolled_global);
+		}
+	}
+	else 
+	{
+			symbol_db_view_recv_signals_from_engine (SYMBOL_DB_VIEW (
+													 symbol_db->dbv_view_tree),
+													 symbol_db->sdbe_project,
+													 TRUE);
+			gtk_widget_show (symbol_db->scrolled_global);
 	}
 }
 
-
-static void
+/**
+ * @return TRUE is a scan process is started, FALSE elsewhere.
+ */
+static gboolean
 do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 {
 	GList * prj_elements_list;
@@ -1463,6 +1577,7 @@ do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 	GHashTable *prj_elements_hash;
 	GPtrArray *to_add_files = NULL;
 	gint i;
+	gint real_added ;
 	
 	pm = anjuta_shell_get_interface (ANJUTA_PLUGIN (sdb_plugin)->shell,
 									 IAnjutaProjectManager, NULL);	
@@ -1577,7 +1692,7 @@ do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 								 sdb_plugin->sdbe_project, FALSE);
 		sdb_plugin->is_offline_scanning = TRUE;		
 		
-		gint real_added = do_add_new_files (sdb_plugin, to_add_files, 
+		real_added = do_add_new_files (sdb_plugin, to_add_files, 
 										   TASK_OFFLINE_CHANGES);
 		
 		DEBUG_PRINT ("going to do add %d files with TASK_OFFLINE_CHANGES",
@@ -1595,6 +1710,8 @@ do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 	g_object_unref (it);
 	g_ptr_array_free (to_add_files, TRUE);
 	g_hash_table_destroy (prj_elements_hash);
+	
+	return real_added > 0 ? TRUE : FALSE;	
 }
 
 /* add a new project */
@@ -1605,11 +1722,13 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	IAnjutaProjectManager *pm;
 	SymbolDBPlugin *sdb_plugin;
 	const gchar *root_uri;
+	gchar *root_dir;
+	GFile *gfile;
 	
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
 
 	/*
-	 * The Globals thing
+	 * The Global System symbols thing
 	 */
 
 	/* is the global db connected? */	
@@ -1632,7 +1751,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	}
 	
 	
-	/* hide it. Default system tags thing: we'll import after abort even 
+	/* Hide the progress bar. Default system tags thing: we'll import after abort even 
 	 * if the preferences says not to automatically scan the packages.
 	 */
 	gtk_widget_hide (sdb_plugin->progress_bar_system);
@@ -1646,7 +1765,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		/* we simulate a project-import-end signal received */
 		do_import_system_sources (sdb_plugin);		
 	}
-		
+	
 	
 	
 	/*
@@ -1657,120 +1776,133 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		
 	g_free (sdb_plugin->project_root_uri);
 	sdb_plugin->project_root_uri = NULL;
-	root_uri = g_value_get_string (value);
-	
-	if (root_uri)
+	if ((root_uri = g_value_get_string (value)) == NULL)
 	{
-		gchar *root_dir;
-		GFile *gfile;
-		gfile = g_file_new_for_uri (root_uri);
-		
-		root_dir = g_file_get_path (gfile);
-		DEBUG_PRINT ("Symbol-DB: added project root_dir %s, name %s", root_dir, 
-					 name);
-		
-		g_object_unref (gfile);
-		
-		/* FIXME: where's the project name itself? */
-		DEBUG_PRINT ("FIXME: where's the project name itself? ");
-		sdb_plugin->project_opened = g_strdup (root_dir);
-		
-		if (root_dir)
-		{
-			gboolean needs_sources_scan = FALSE;
-			gboolean project_exist = FALSE;
-			GHashTable* lang_hash;
-			guint id;
-				
-			lang_hash = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, 
-											  sources_array_free);
-
-			/* is it a fresh-new project? is it an imported project with 
-			 * no 'new' symbol-db database but the 'old' one symbol-browser? 
-			 */
-			if (symbol_db_engine_db_exists (sdb_plugin->sdbe_project, 
-											root_dir) == FALSE)
-			{
-				DEBUG_PRINT ("%s", "Symbol-DB: project does not exist");
-				needs_sources_scan = TRUE;
-				project_exist = FALSE;
-			}
-			else 
-			{
-				project_exist = TRUE;
-			}
-
-			/* we'll use the same values for db_directory and project_directory */
-			DEBUG_PRINT ("opening db %s and project_dir %s", root_dir, root_dir);
-			if (symbol_db_engine_open_db (sdb_plugin->sdbe_project, root_dir, 
-										  root_dir) == FALSE)
-			{
-				g_error ("Symbol-DB: error in opening db");
-			}
-
-			/* if project did not exist add a new project */
-			if (project_exist == FALSE)
-			{
-				DEBUG_PRINT ("%s", "Symbol-DB: creating new project.");
-				symbol_db_engine_add_new_project (sdb_plugin->sdbe_project,
-												  NULL,	/* still no workspace logic */
-												  sdb_plugin->project_opened);
-			}
-
-			/*
-			 * we need an initial import 
-			 */
-			if (needs_sources_scan == TRUE)
-			{
-				DEBUG_PRINT ("%s", "Symbol-DB: importing sources...");
-				do_import_project_sources (plugin, pm, root_dir);
-			}
-			else	
-			{
-				/*
-				 * no import needed. But we may have aborted the scan of sources in 
-				 * a previous session..
-				 */				
-				GPtrArray *sources_array = NULL;				
-				
-				sources_array = 
-					symbol_db_engine_get_files_with_zero_symbols (sdb_plugin->sdbe_project);
-
-				if (sources_array != NULL && sources_array->len > 0) 
-				{				
-					do_import_project_sources_after_abort (plugin, sources_array);
-					
-					g_ptr_array_foreach (sources_array, (GFunc)g_free, NULL);
-					g_ptr_array_free (sources_array, TRUE);
-				}
-				
-				/* check for offline changes */				
-				do_check_offline_files_changed (sdb_plugin);								
-				
-				/* update any files of the project which isn't up-to-date */
-				do_update_project_symbols (sdb_plugin, root_dir);
-			}
-			gtk_progress_bar_set_text (GTK_PROGRESS_BAR (sdb_plugin->progress_bar_project),
-									   _("Populating symbols' db..."));
-			id = g_idle_add ((GSourceFunc) gtk_progress_bar_pulse, 
-							 sdb_plugin->progress_bar_project);
-			gtk_widget_show (sdb_plugin->progress_bar_project);
-			
-			/* open symbol view, the global symbols gtktree */
-			symbol_db_view_open (SYMBOL_DB_VIEW (sdb_plugin->dbv_view_tree),
-								 sdb_plugin->sdbe_project);
-			g_source_remove (id);
-			gtk_widget_hide (sdb_plugin->progress_bar_project);
-
-			/* root dir */
-			sdb_plugin->project_root_dir = root_dir;
-			
-			g_hash_table_unref (lang_hash);			
-		}
-		/* this is uri */
-		sdb_plugin->project_root_uri = g_strdup (root_uri);
+		DEBUG_PRINT ("Warning, root_uri for project is NULL");
+		return;
 	}
 
+	
+	gfile = g_file_new_for_uri (root_uri);
+		
+	root_dir = g_file_get_path (gfile);
+	DEBUG_PRINT ("Symbol-DB: added project root_dir %s, name %s", root_dir, 
+				 name);
+		
+	g_object_unref (gfile);
+		
+	/* FIXME: where's the project name itself? */
+	DEBUG_PRINT ("FIXME: where's the project name itself? using %s", root_dir);
+	sdb_plugin->project_opened = g_strdup (root_dir);
+	
+	if (root_dir)
+	{
+		gboolean needs_sources_scan = FALSE;
+		gboolean project_exist = FALSE;
+		GHashTable* lang_hash;
+		guint id;
+			
+		lang_hash = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, 
+										  sources_array_free);
+
+		/* is it a fresh-new project? is it an imported project with 
+		 * no 'new' symbol-db database but the 'old' one symbol-browser? 
+		 */
+		if (symbol_db_engine_db_exists (sdb_plugin->sdbe_project, 
+										root_dir) == FALSE)
+		{
+			DEBUG_PRINT ("Project %s does not exist", root_dir);
+			needs_sources_scan = TRUE;
+			project_exist = FALSE;
+		}
+		else 
+		{
+			project_exist = TRUE;
+		}
+
+		/* we'll use the same values for db_directory and project_directory */
+		DEBUG_PRINT ("Opening db %s and project_dir %s", root_dir, root_dir);
+		if (symbol_db_engine_open_db (sdb_plugin->sdbe_project, root_dir, 
+										  root_dir) == FALSE)
+		{
+			g_error ("*** Error in opening db ***");
+		}
+			
+		/* if project did not exist add a new project */
+		if (project_exist == FALSE)
+		{
+			DEBUG_PRINT ("Creating new project.");
+			symbol_db_engine_add_new_project (sdb_plugin->sdbe_project,
+											  NULL,	/* still no workspace logic */
+											  sdb_plugin->project_opened);
+		}
+
+		/*
+		 * we need an initial import 
+		 */
+		if (needs_sources_scan == TRUE)
+		{
+			DEBUG_PRINT ("Importing sources.");
+			do_import_project_sources (plugin, pm, root_dir);
+		}
+		else	
+		{
+			/*
+			 * no import needed. But we may have aborted the scan of sources in 
+			 * a previous session..
+			 */				
+			GPtrArray *sources_array = NULL;				
+			gboolean flag_offline;
+			gboolean flag_update;
+			
+			
+			sources_array = 
+				symbol_db_engine_get_files_with_zero_symbols (sdb_plugin->sdbe_project);
+
+			if (sources_array != NULL && sources_array->len > 0) 
+			{				
+				do_import_project_sources_after_abort (plugin, sources_array);
+				
+				g_ptr_array_foreach (sources_array, (GFunc)g_free, NULL);
+				g_ptr_array_free (sources_array, TRUE);
+			}
+				
+			/* check for offline changes */				
+			flag_offline = do_check_offline_files_changed (sdb_plugin);
+				
+			/* update any files of the project which isn't up-to-date */
+			flag_update = do_update_project_symbols (sdb_plugin, root_dir);
+			
+			/* if they're both false then there won't be a place where
+			 * the do_check_languages_count () is called. Check the returns
+			 * and to it here
+			 */
+			if (flag_offline == FALSE && flag_update == FALSE)
+			{
+				/* check for the number of languages used in the opened project. */
+				do_check_languages_count (sdb_plugin);				
+			}				
+		}
+		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (sdb_plugin->progress_bar_project),
+								   _("Populating symbols' db..."));
+		id = g_idle_add ((GSourceFunc) gtk_progress_bar_pulse, 
+						 sdb_plugin->progress_bar_project);
+		gtk_widget_show (sdb_plugin->progress_bar_project);
+		
+		/* open symbol view, the global symbols gtktree */
+		symbol_db_view_open (SYMBOL_DB_VIEW (sdb_plugin->dbv_view_tree),
+							 sdb_plugin->sdbe_project);
+		g_source_remove (id);
+		gtk_widget_hide (sdb_plugin->progress_bar_project);
+
+		/* root dir */
+		sdb_plugin->project_root_dir = root_dir;
+			
+		g_hash_table_unref (lang_hash);			
+	}
+	/* this is uri */
+	sdb_plugin->project_root_uri = g_strdup (root_uri);	
+
 	g_signal_connect (G_OBJECT (pm), "element_added",
 					  G_CALLBACK (on_project_element_added), sdb_plugin);
 	g_signal_connect (G_OBJECT (pm), "element_removed",
@@ -1845,15 +1977,17 @@ on_scan_end_manager (SymbolDBEngine *dbe, gint process_id,
 		case TASK_IMPORT_PROJECT_AFTER_ABORT:			
 		{			
 			DEBUG_PRINT ("received TASK_IMPORT_PROJECT (AFTER_ABORT)");
-			project_import_scan_end (dbe, process_id, symbol_db);
+			on_project_import_scan_end (dbe, process_id, symbol_db);
 			
 			/* get preferences about the parallel scan */
 			gboolean parallel_scan = anjuta_preferences_get_int (symbol_db->prefs, 
 														 PARALLEL_SCAN); 
 			
+			do_check_languages_count (symbol_db);
+			
 			/* check the system population has a parallel fashion or not. */			 
 			if (parallel_scan == FALSE)
-				do_import_system_sources (symbol_db);
+				do_import_system_sources (symbol_db);			
 		}
 			break;			
 			
@@ -1865,20 +1999,23 @@ on_scan_end_manager (SymbolDBEngine *dbe, gint process_id,
 		case TASK_ELEMENT_ADDED:
 			DEBUG_PRINT ("received TASK_ELEMENT_ADDED");
 			symbol_db->is_adding_element = FALSE;
+			do_check_languages_count (symbol_db);
 			break;
 			
-		case TASK_OFFLINE_CHANGES:
-		{
+		case TASK_OFFLINE_CHANGES:		
 			DEBUG_PRINT ("received TASK_OFFLINE_CHANGES");
-			symbol_db->is_offline_scanning = FALSE;
-		}
+			symbol_db->is_offline_scanning = FALSE;		
+			do_check_languages_count (symbol_db);
 			break;
 			
-		case TASK_PROJECT_UPDATE:
-		{
+		case TASK_PROJECT_UPDATE:		
 			DEBUG_PRINT ("received TASK_PROJECT_UPDATE");
 			symbol_db->is_project_updating = FALSE;
-		}
+			break;
+
+		case TASK_FILE_UPDATE:
+			DEBUG_PRINT ("received TASK_FILE_UPDATE");
+			break;
 			
 		default:
 			DEBUG_PRINT ("Don't know what to to with task_registered %d", 
