@@ -25,8 +25,7 @@
 #include <sys/wait.h>
 #include <dirent.h>
 #include <string.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkliststore.h>
+#include <gtk/gtk.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-launcher.h>
 #include <libanjuta/interfaces/ianjuta-language.h>
@@ -89,24 +88,26 @@ destroy_parseable_data (ParseableData *pdata)
 G_DEFINE_TYPE (SymbolDBPrefs, sdb_prefs, G_TYPE_OBJECT);
 
 static void 
-on_prefs_executable_changed (GtkFileChooser *chooser,
+on_prefs_executable_changed (/*GtkFileChooser *chooser,*/ GtkComboBox *chooser,
                              gpointer user_data)
 {
-	gchar *new_file;
+	const gchar *new_file;
 	SymbolDBPrefs *sdbp;
 	SymbolDBPrefsPriv *priv;
 	
 	sdbp = SYMBOL_DB_PREFS (user_data);
 	priv = sdbp->priv;
 	
-	new_file = gtk_file_chooser_get_filename (chooser);
+/*	new_file = gtk_file_chooser_get_filename (chooser);*/
+	new_file = gtk_entry_get_text  (GTK_ENTRY (chooser));
+		
 	DEBUG_PRINT ("on_prefs_executable_changed (): new executable selected %s", 
 				 new_file);
 	if (new_file != NULL) 
 	{
 		GtkWidget *fchooser;
 		fchooser = 	glade_xml_get_widget (priv->prefs_gxml, CTAGS_PREFS_KEY);	
-		gtk_widget_set_sensitive (fchooser, TRUE);
+		/*gtk_widget_set_sensitive (fchooser, TRUE);*/
 		
 		anjuta_preferences_set (priv->prefs, CTAGS_PREFS_KEY,
 							new_file);
@@ -115,21 +116,13 @@ on_prefs_executable_changed (GtkFileChooser *chooser,
 		symbol_db_engine_set_ctags_path (priv->sdbe_project, new_file);
 		symbol_db_engine_set_ctags_path (priv->sdbe_globals, new_file);
 	}
-	
-	g_free (new_file);
 }
 
 static void
 on_gconf_notify_prefs (GConfClient *gclient, guint cnxn_id,
 					   GConfEntry *entry, gpointer user_data)
 {
-	DEBUG_PRINT ("on_gconf_notify_prefs ()");
-}
-
-static gint 
-pkg_list_compare (gconstpointer a, gconstpointer b)
-{
-	return strcmp ((const gchar*)a, (const gchar*)b);
+	DEBUG_PRINT ("%s", "on_gconf_notify_prefs ()");
 }
 
 static void
@@ -192,7 +185,7 @@ on_listall_exit (AnjutaLauncher * launcher, int child_pid,
 	priv = sdbp->priv;
 	store = priv->prefs_list_store;
 	
-	DEBUG_PRINT ("on_listall_exit ()");
+	DEBUG_PRINT ("%s", "on_listall_exit ()");
 
 	g_signal_handlers_disconnect_by_func (launcher, on_listall_exit,
 										  user_data);	
@@ -214,7 +207,7 @@ on_listall_exit (AnjutaLauncher * launcher, int child_pid,
 		return;
 	}
 
-	priv->pkg_list = g_list_sort (priv->pkg_list, pkg_list_compare);
+	priv->pkg_list = g_list_sort (priv->pkg_list, symbol_db_glist_compare_func);
 	item = priv->pkg_list;
 	
 	while (item != NULL)
@@ -329,7 +322,7 @@ on_tag_load_toggled (GtkCellRendererToggle *cell, char *path_str,
 	
 	priv = sdbp->priv;
 	
-	DEBUG_PRINT ("on_tag_load_toggled ()");
+	DEBUG_PRINT ("%s", "on_tag_load_toggled ()");
 	
 	store = priv->prefs_list_store;
 	path = gtk_tree_path_new_from_string (path_str);
@@ -358,7 +351,7 @@ on_tag_load_toggled (GtkCellRendererToggle *cell, char *path_str,
 }
 
 static void
-on_check_button_toggled (GtkToggleButton *togglebutton, SymbolDBPrefs *sdbp)
+on_autoscan_button_toggled (GtkToggleButton *togglebutton, SymbolDBPrefs *sdbp)
 {
 	SymbolDBPrefsPriv *priv;	
 	gboolean check_button_value;
@@ -368,7 +361,7 @@ on_check_button_toggled (GtkToggleButton *togglebutton, SymbolDBPrefs *sdbp)
 	check_button = glade_xml_get_widget (priv->prefs_gxml, PROJECT_AUTOSCAN);
 
 	check_button_value =  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_button));
-	DEBUG_PRINT ("on_check_button_toggled ()");
+	DEBUG_PRINT ("%s", "on_check_button_toggled ()");
 	anjuta_preferences_set_int (priv->prefs, PROJECT_AUTOSCAN, check_button_value);
 
 }
@@ -384,26 +377,41 @@ on_update_button_toggled (GtkToggleButton *togglebutton, SymbolDBPrefs *sdbp)
 	update_button = glade_xml_get_widget (priv->prefs_gxml, BUFFER_AUTOSCAN);
 
 	update_button_value =  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (update_button));
-	DEBUG_PRINT ("on_update_button_toggled ()");
+	DEBUG_PRINT ("%s", "on_update_button_toggled ()");
 	anjuta_preferences_set_int (priv->prefs, BUFFER_AUTOSCAN, update_button_value);	
 
 	g_signal_emit (sdbp, signals[BUFFER_UPDATE_TOGGLED], 0, update_button_value);
 }
 
+static void
+on_parallel_button_toggled (GtkToggleButton *togglebutton, SymbolDBPrefs *sdbp)
+{
+	SymbolDBPrefsPriv *priv;	
+	gboolean parallel_button_value;
+	priv = sdbp->priv;
+	GtkWidget *parallel_button;
+	
+	parallel_button = glade_xml_get_widget (priv->prefs_gxml, PARALLEL_SCAN);
+
+	parallel_button_value =  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (parallel_button));
+	DEBUG_PRINT ("%s", "on_parallel_button_toggled ()");
+	anjuta_preferences_set_int (priv->prefs, PARALLEL_SCAN, parallel_button_value);	
+}
+
 static void
 sdb_prefs_init1 (SymbolDBPrefs *sdbp)
 {
 	SymbolDBPrefsPriv *priv;
 	GtkWidget *fchooser;
-	GtkWidget *check_button, *update_button;
-	gboolean check_button_value;
+	GtkWidget *check_button, *update_button, *parallel_button;
+	gboolean check_button_value, update_button_value, parallel_button_value;
 	gchar *ctags_value;
 
 	priv = sdbp->priv;
 
 	fchooser = 	glade_xml_get_widget (priv->prefs_gxml, CTAGS_PREFS_KEY);
 	/* we will reactivate it after the listall has been finished */
-	gtk_widget_set_sensitive (fchooser, FALSE);
+	/*gtk_widget_set_sensitive (fchooser, FALSE);*/
 			
 	anjuta_preferences_add_page (priv->prefs, 
 								 priv->prefs_gxml, 
@@ -419,12 +427,25 @@ sdb_prefs_init1 (SymbolDBPrefs *sdbp)
 	}
 	
 	DEBUG_PRINT ("select ->%s<-", ctags_value);	
+	
+	/*
+	 * GtkFileChooser support disabled here because it was too slow.
+	 * Bug #551384 has been filed. Let's see what happens...
+	 * 
+	 */
+	
+#if 0
 	/* FIXME: wtf?! */
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fchooser), ctags_value);
 	gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (fchooser), ctags_value);
 	
 	g_signal_connect (G_OBJECT (fchooser), "selection-changed",
 					  G_CALLBACK (on_prefs_executable_changed), sdbp);
+#endif
+	
+	g_signal_connect (G_OBJECT (fchooser), "changed",
+					  G_CALLBACK (on_prefs_executable_changed), sdbp);	
+	
 
 	priv->prefs_notify_id = anjuta_preferences_notify_add (priv->prefs, 
 												CTAGS_PREFS_KEY, 
@@ -434,14 +455,21 @@ sdb_prefs_init1 (SymbolDBPrefs *sdbp)
 	
 	check_button = glade_xml_get_widget (priv->prefs_gxml, PROJECT_AUTOSCAN);
 	g_signal_connect (G_OBJECT (check_button), "toggled", 
-					  G_CALLBACK (on_check_button_toggled), sdbp);
+					  G_CALLBACK (on_autoscan_button_toggled), sdbp);
 	check_button_value = anjuta_preferences_get_int (priv->prefs, PROJECT_AUTOSCAN);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), check_button_value);
 
 	update_button = glade_xml_get_widget (priv->prefs_gxml, BUFFER_AUTOSCAN);
 	g_signal_connect (G_OBJECT (update_button), "toggled", 
-					  G_CALLBACK (on_update_button_toggled), sdbp);	
+					  G_CALLBACK (on_update_button_toggled), sdbp);
+	update_button_value = anjuta_preferences_get_int (priv->prefs, BUFFER_AUTOSCAN);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (update_button), update_button_value);
 	
+	parallel_button	= glade_xml_get_widget (priv->prefs_gxml, PARALLEL_SCAN);
+	g_signal_connect (G_OBJECT (parallel_button), "toggled", 
+					  G_CALLBACK (on_parallel_button_toggled), sdbp);
+	parallel_button_value = anjuta_preferences_get_int (priv->prefs, PARALLEL_SCAN);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (parallel_button), parallel_button_value);
 	
 	g_free (ctags_value);
 }
@@ -463,14 +491,14 @@ sdb_prefs_init (SymbolDBPrefs *object)
 	
 	priv->pkg_list = NULL;
 	
-	DEBUG_PRINT ("symbol_db_prefs_init ()");
+	DEBUG_PRINT ("%s", "symbol_db_prefs_init ()");
 	
 	if (priv->prefs_gxml == NULL)
 	{
 		/* Create the preferences page */
 		priv->prefs_gxml = glade_xml_new (GLADE_FILE, GLADE_ROOT, NULL);	
 	}		
-	
+
 	/* init GtkListStore */
 	if (priv->prefs_list_store == NULL) 
 	{
@@ -545,7 +573,7 @@ sdb_prefs_finalize (GObject *object)
 	sdbp = SYMBOL_DB_PREFS (object);
 	priv = sdbp->priv;
 	
-	DEBUG_PRINT ("symbol_db_prefs_finalize ()");
+	DEBUG_PRINT ("%s", "symbol_db_prefs_finalize ()");
 	
 	anjuta_preferences_notify_remove(priv->prefs, priv->prefs_notify_id);
 	anjuta_preferences_remove_page(priv->prefs, _("Symbol Database"));
@@ -637,7 +665,7 @@ symbol_db_prefs_new (SymbolDBSystem *sdbs, SymbolDBEngine *sdbe_project,
 	while (item != NULL)
 	{
 		g_hash_table_insert (priv->enabled_packages_hash, (gpointer)g_strdup (item->data), 
-							 (gpointer)TRUE);
+							 GINT_TO_POINTER (TRUE));
 		item = item->next;
 	}	
 	
